@@ -1,5 +1,5 @@
 /*
- * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @copyright Copyright (c) Open-Xchange GmbH, Germany <info@open-xchange.com>
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -465,12 +465,13 @@ public abstract class AbstractGrizzlyWebSocketApplication<S extends SessionBound
 
             ConfigView view = configViewFactory.getView(session.getUserId(), session.getContextId());
             ComposedConfigProperty<Boolean> property = view.property("com.openexchange.websockets.enabled", boolean.class);
-            if (null == property || !property.isDefined()) {
+            if (null == property) {
                 // Default is true
                 return true;
             }
 
-            return property.get().booleanValue();
+            Boolean b = property.get();
+            return b == null ? true : b.booleanValue();
         } catch (OXException e) {
             throw new HandshakeException(e.getPlainLogMessage());
         }
